AccessDecision class

Represents a detailed access-control decision.

Constructors

AccessDecision({required bool allowed, List<String> missingRoles = const [], List<String> missingPermissions = const [], bool failedCondition = false, String? reasonCode})
const
AccessDecision.allow()
factory
AccessDecision.deny({List<String> missingRoles = const [], List<String> missingPermissions = const [], bool failedCondition = false, String? reasonCode})
factory

Properties

allowed bool
final
failedCondition bool
final
hashCode int
The hash code for this object.
no setterinherited
missingPermissions List<String>
final
missingRoles List<String>
final
reasonCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited