Guard class

A simple class to hold and manage user roles.

Implementers

Constructors

Guard()

Properties

currentPermissions List<String>
no setter
currentRoles List<String>
Get the current user roles.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setUserPermissions(List<String> permissions) → void
setUserRoles(List<String> roles) → void
Set or update current user roles.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited