GuardNotifier class

Reactive variant of Guard that notifies listeners on changes.

Inheritance
Implemented types

Constructors

GuardNotifier()

Properties

currentPermissions List<String>
no setteroverride
currentRoles List<String>
Get the current user roles.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setUserPermissions(List<String> permissions) → void
override
setUserRoles(List<String> roles) → void
Set or update current user roles.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited