ScheduleParser class

Parses and evaluates cron expressions with support for wildcards, lists, ranges, and steps (e.g. */5, 1-10/2).

Constructors

ScheduleParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

matches(String cron, DateTime now) bool
normalize(String cron) String
validate(String cron) CronParseResult