GuardConfig class
Configuration for ui_guard behavior.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- developerOverrideEnabled ↔ bool
-
If true, all access restrictions are bypassed for development/testing.
This allows developers to test UI without worrying about role checks.
Set to false in production builds.
Default is false.
This should be used with caution as it disables all role-based access checks.
This is useful for development and testing purposes only.
It should not be enabled in production environments.
Example usage:
getter/setter pair